@@ -5,30 +5,26 @@
 #include "{{ output_file_header }}"
 
 
+#include <tests/testcore.h>
+#include <tests/autotestshell.h>
+
+
 QTEST_GUILESS_MAIN({{ name }});
 
 
+using namespace KDevelop;
+
+
 void {{ name }}::initTestCase()
 {
-    // Called before the first testfunction is executed
+    AutoTestShell::init();
+    TestCore::initialize(Core::NoUi);
 }
 
 
 void {{ name }}::cleanupTestCase()
 {
-    // Called after the last testfunction was executed
-}
-
-
-void {{ name }}::init()
-{
-    // Called before each testfunction is executed
-}
-
-
-void {{ name }}::cleanup()
-{
-    // Called after every testfunction
+    TestCore::shutdown();
 }
 
 
